# Installation instructions for students

> Students must have installed Anaconda already.

#### Please follow these steps:

1. Open Anaconda.
2. Open the Jupyter Lab app.
3. Navigate to the course directory or create a new course directory.
4. Download the installation script.
	+ For MacOS, download [**install_carpo_osx.py**](../installation-script/install_carpo_osx.py) 
	+ For Windows, download [**install_carpo_win.py**](../installation-script/install_carpo_win.py) 
5. Upload the script to the course directory in Jupyter Lab.
6. Click on "+" and open a new Terminal.
7. Execute this command in Terminal.
	+ For MacOS: **python install_carpo_osx.py**
	+ For Windows: **python install_carpo_win.py** 
8. Close Jupyter Lab and Anaconda.
9. Open the folder that has the script and double click on `RUN_JUPYTER_LAB.command`.
# Configuration of the extension 
Your instructor will walk you through the configuration process.
